Module discord_bot_light_app

Behaviours: application.

Function Index

get_bot_pid/0Get the bot client process PID.
is_bot_running/0Check if the bot is currently running.
start/2Start the Discord bot application This function gets the Discord token from environment variables and optionally configures a command handler module.
stop/1Stop the Discord bot application.

Function Details

get_bot_pid/0

get_bot_pid() -> {ok, pid()} | {error, not_found}

Get the bot client process PID

is_bot_running/0

is_bot_running() -> boolean()

Check if the bot is currently running

start/2

start(StartType, StartArgs) -> any()

Start the Discord bot application This function gets the Discord token from environment variables and optionally configures a command handler module

stop/1

stop(State) -> any()

Stop the Discord bot application


Generated by EDoc