Behaviours: application.
| get_bot_pid/0 | Get the bot client process PID. |
| is_bot_running/0 | Check if the bot is currently running. |
| start/2 | Start the Discord bot application This function gets the Discord token from environment variables and optionally configures a command handler module. |
| stop/1 | Stop the Discord bot application. |
get_bot_pid() -> {ok, pid()} | {error, not_found}
Get the bot client process PID
is_bot_running() -> boolean()
Check if the bot is currently running
start(StartType, StartArgs) -> any()
Start the Discord bot application This function gets the Discord token from environment variables and optionally configures a command handler module
stop(State) -> any()
Stop the Discord bot application
Generated by EDoc